@@ -50,7 +50,7 @@ char last_error[ERROR_BUFFER_SIZE];
 
 void version(void)
 {
-	fprintf(stderr, "HTTPing v" VERSION ", (C) 2003-2005 folkert@vanheusden.com\n");
+	fprintf(stderr, "HTTPing v" VERSION ", (C) 2003-2008 folkert@vanheusden.com\n");
 #ifndef NO_SSL
 	fprintf(stderr, "SSL support included\n");
 #endif
@@ -66,6 +66,7 @@ void usage(void)
 	fprintf(stderr, "-i interval	delay between each connect\n");
 	fprintf(stderr, "-t timeout	timeout (default: 30s)\n");
 	fprintf(stderr, "-s		show statuscodes\n");
+	fprintf(stderr, "-S             split time in connect-time and processing time\n");
 	fprintf(stderr, "-G		do a GET request instead of HEAD (read the\n");
 	fprintf(stderr, "		contents of the page as well)\n");
 	fprintf(stderr, "-b		show transfer speed in KB/s (use with -G)\n");
@@ -160,16 +161,21 @@ int main(int argc, char *argv[])
 	BIO *s_bio;
 	struct sockaddr_in bind_to;
 	char bind_to_valid = 0;
+	char split = 0;
 
 	if (page_size == -1)
 		page_size = 4096;
 
 	buffer = (char *)mymalloc(page_size, "receive buffer");
 
-	while((c = getopt(argc, argv, "y:XL:bBg:h:p:c:i:Gx:t:o:e:falqsmV?I:R:rn:N:z")) != -1)
+	while((c = getopt(argc, argv, "Sy:XL:bBg:h:p:c:i:Gx:t:o:e:falqsmV?I:R:rn:N:z")) != -1)
 	{
 		switch(c)
 		{
+			case 'S':
+				split = 1;
+				break;
+
 			case 'y':
 				{
 					char *dummy = strchr(optarg, ':');
@@ -454,7 +460,7 @@ int main(int argc, char *argv[])
 	while((curncount < count || count == -1) && stop == 0)
 	{
 		double ms;
-		double dstart, dend;
+		double dstart, dend, dafter_connect;
 		char *reply;
 		int Bps = 0;
 		char is_compressed = 0;
@@ -516,6 +522,8 @@ int main(int argc, char *argv[])
 				}
 #endif
 			}
+			if (split)
+				dafter_connect = get_ts();
 
 			if (fd < 0)
 			{
@@ -696,7 +704,14 @@ int main(int argc, char *argv[])
 			}
 			else if (!quiet && !nagios_mode)
 			{
-				printf("connected to %s:%d, seq=%d time=%.2f ms %s", hostname, portnr, curncount-1, ms, sc?sc:"");
+				if (split)
+				{
+					printf("connected to %s:%d, seq=%d time=%.2f+%.2f=%.2f ms %s", hostname, portnr, curncount-1, (dafter_connect - dstart) * 1000.0, (dend - dafter_connect) * 1000.0, ms, sc?sc:"");
+				}
+				else
+				{
+					printf("connected to %s:%d, seq=%d time=%.2f ms %s", hostname, portnr, curncount-1, ms, sc?sc:"");
+				}
 
 				if (show_Bps)
 				{
